//******************************************************************************
//  Demo Application for MSP430/LMP91200 Interface Code Library
//  ADC16S626 Data Capture
//
//                MSP430F5529 (USB2ANY)
//             ---------------------
//         /|\|                 XIN|-
//          | |                    |  
//          --|RST             XOUT|-
//            |                    |
//            |       P4.5/UCA1SOMI|<-- ADC16S626_SDO 
//            |        P4.0/UCA1CLK|--> ADC16S626_CLK 
//            |                P2.0|--> ADC16S626_CSB 
//            |                    | 
//            |                    | 
//
//   Vishy Natarajan
//   Texas Instruments Inc.
//   March 2012
//   Built with CCE Version: 4.2 and IAR Embedded Workbench Version:  5.3x
//******************************************************************************
// Change Log:
//******************************************************************************
// Version:  1.00
// Comments: Initial Release Version
//******************************************************************************
/*  Copyright 2011-2012 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user who
  downloaded the software, his/her employer (which must be your employer) and
  Texas Instruments Incorporated (the "License"). You may not use this Software
  unless you agree to abide by the terms of the License. The License limits your
  use, and you acknowledge, that the Software may not be modified, copied or
  distributed unless embedded on a Texas Instruments microcontroller which is 
  integrated into your product. Other than for the foregoing purpose, you may 
  not use, reproduce, copy, prepare derivative works of, modify, distribute, 
  perform, display or sell this Software and/or its documentation for any 
  purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL TEXAS
  INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL
  EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT
  LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL
  DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS,
  TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES (INCLUDING BUT NOT
  LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
*******************************************************************************/

#include <stdint.h>
#include "TI_LMP91000.h"
#include "TI_LMP91000_register_settings.h"
#include "TI_MSP430.h"
#include "TI_MSP430_hardware_board.h"
#include "TI_MSP430_i2c.h"

// Choose SPI port to connect to ADC16S626 (enable only one of the two #defines)
#define TI_ADC16S626_SPI_BITBANG                                               // BITBANG SPI connected to ADC16S626 SPI pins
//#define TI_ADC16S626_SPI_USCIA1_5xx                                            // USCIA1_5xx connected to ADC16S626 SPI pins

//******************************************************************************
// If Bit Bang is used for ADC161 SPI connection (Default)
//******************************************************************************
#ifdef TI_ADC16S626_SPI_BITBANG
uint16_t TI_ADC16S626_SPI_bitbang_in(void);
//------------------------------------------------------------------------------
//  void TI_ADC16S626_SPISetup(void)
//
//  DESCRIPTION:
//  Configures the assigned interface to function as a SPI port and
//  initializes it.
//------------------------------------------------------------------------------
void TI_ADC16S626_SPISetup(void)
{
  TI_ADC16S626_CSn_PxOUT |= TI_ADC16S626_CSn_PIN;
  TI_ADC16S626_CSn_PxDIR |= TI_ADC16S626_CSn_PIN;                              // /CS disable

  // Disable special function on bitbang pins
  TI_ADC16S626_SPI_BITBANG_SIMO_PxSEL &= ~TI_ADC16S626_SPI_BITBANG_SIMO;
  TI_ADC16S626_SPI_BITBANG_SOMI_PxSEL &= ~TI_ADC16S626_SPI_BITBANG_SOMI;
  TI_ADC16S626_SPI_BITBANG_UCLK_PxSEL &= ~TI_ADC16S626_SPI_BITBANG_UCLK;
  
  // Config bitbang pins: SIMO high and UCLK low
  TI_ADC16S626_SPI_BITBANG_PxOUT |= TI_ADC16S626_SPI_BITBANG_SIMO;
  TI_ADC16S626_SPI_BITBANG_PxOUT &= ~TI_ADC16S626_SPI_BITBANG_UCLK; 
  
  // Config bitbang pins direction: SIMO, UCLK as OUT & SOMI as IN
  TI_ADC16S626_SPI_BITBANG_PxDIR |= TI_ADC16S626_SPI_BITBANG_SIMO | TI_ADC16S626_SPI_BITBANG_UCLK;
  TI_ADC16S626_SPI_BITBANG_PxDIR &= ~TI_ADC16S626_SPI_BITBANG_SOMI;
}
//------------------------------------------------------------------------------
// uint16_t TI_ADC16S626_SPI_bitbang_in(void)
// Description Input 16-bit value using selected bit-bang pins
//------------------------------------------------------------------------------
uint16_t TI_ADC16S626_SPI_bitbang_in(void)
{
  uint16_t x=0,shift=0;
  uint8_t y;

  // Determine how many bit positions SOMI is from least-significant bit
  x = TI_ADC16S626_SPI_BITBANG_SOMI;
  while(x>1)
  {
    shift++;
    x = x >> 1;
  };

  x = 0;
  for(y=18;y>0;y--)
  {
    TI_ADC16S626_SPI_BITBANG_PxOUT &= ~TI_ADC16S626_SPI_BITBANG_UCLK;          // Set clock low
    TI_ADC16S626_SPI_BITBANG_PxOUT |= TI_ADC16S626_SPI_BITBANG_UCLK;           // Set clock high 

    x = x << 1;                                                                // Make room for next bit
    x = x | ((TI_ADC16S626_SPI_BITBANG_PxIN & TI_ADC16S626_SPI_BITBANG_SOMI) >> shift);    
                                                                               // Store next bit
  }
  TI_ADC16S626_SPI_BITBANG_PxOUT &= ~TI_ADC16S626_SPI_BITBANG_UCLK;            // Set clock low   
  return(x);
}
//------------------------------------------------------------------------------
//  uint16_t TI_ADC16S626_SPIReadReg(void)
//
//  DESCRIPTION:
//  Reads the adc output
//------------------------------------------------------------------------------
uint16_t TI_ADC16S626_SPIReadReg(void)
{
  uint16_t x;
  
  TI_ADC16S626_CSn_PxOUT &= ~TI_ADC16S626_CSn_PIN;                             // /CS enable
  x = TI_ADC16S626_SPI_bitbang_in();                                           // Read data   
  TI_ADC16S626_CSn_PxOUT |= TI_ADC16S626_CSn_PIN;                              // /CS disable  
  
  return x;
}
//------------------------------------------------------------------------------
#endif
//******************************************************************************
// If USCIA1_5xx is used for ADC161 SPI connection  
//******************************************************************************
#ifdef TI_ADC16S626_SPI_USCIA1_5xx
//------------------------------------------------------------------------------
//  void TI_ADC16S626_SPISetup(void)
//
//  DESCRIPTION:
//  Configures the assigned interface to function as a SPI port and
//  initializes it.
//------------------------------------------------------------------------------
void TI_ADC16S626_SPISetup(void)
{
  TI_ADC16S626_CSn_PxOUT |= TI_ADC16S626_CSn_PIN;
  TI_ADC16S626_CSn_PxDIR |= TI_ADC16S626_CSn_PIN;                              // /CS disable

  UCA1CTL1 |= UCSWRST;                                                         // **Disable USCI state machine**
  UCA1CTL0 |= UCMST+UCCKPL+UCMSB+UCSYNC;                                       // 3-pin, 8-bit SPI master 
  UCA1CTL1 |= UCSSEL_2;                                                        // SMCLK
  UCA1BR0 = 0x04;                                                              // UCLK/4
  UCA1BR1 = 0;
  
  TI_ADC16S626_SPI_USCIA1_SIMO_PxSEL |= TI_ADC16S626_SPI_USCIA1_SIMO;          // SPI option select
  TI_ADC16S626_SPI_USCIA1_SOMI_PxSEL |= TI_ADC16S626_SPI_USCIA1_SOMI;              
  TI_ADC16S626_SPI_USCIA1_UCLK_PxSEL |= TI_ADC16S626_SPI_USCIA1_UCLK;
                                                                               
  TI_ADC16S626_SPI_USCIA1_SIMO_PxDIR |= TI_ADC16S626_SPI_USCIA1_SIMO;          // SPI TXD out direction
  TI_ADC16S626_SPI_USCIA1_UCLK_PxDIR |= TI_ADC16S626_SPI_USCIA1_UCLK;  
  
  UCA1CTL1 &= ~UCSWRST;                                                        // **Initialize USCI state machine**
}
//------------------------------------------------------------------------------
//  uint16_t TI_ADC16S626_SPIReadReg(void)
//
//  DESCRIPTION:
//  Writes "value" to configuration register. Returns the previous value
//  in the configuration register.
//------------------------------------------------------------------------------
uint16_t TI_ADC16S626_SPIReadReg(void)
{
  uint16_t x=0;
  
  TI_ADC16S626_CSn_PxOUT &= ~TI_ADC16S626_CSn_PIN;                             // /CS enable 
  
  while (!(UCA1IFG&UCTXIFG));                                                  // Wait for TXBUF ready
  UCA1TXBUF = 0x0;                                                             // Send dummy data to read msb     
  
  while (UCA1STAT & UCBUSY);                                                   // Wait for TX complete
  x = UCA1RXBUF;                                                               // Read msb
  
  while (!(UCA1IFG & UCTXIFG));                                                // Wait for TXBUF ready
  UCA1TXBUF = 0x0;                                                             // Send dummy data to read lsb  
  
  while (UCA1STAT & UCBUSY);                                                   // Wait for TX complete
  x = (x << 8) | UCA1RXBUF;                                                    // Read lsb & append 
  
  while (!(UCA1IFG & UCTXIFG));                                                // Wait for TXBUF ready
  UCA1TXBUF = 0x0;                                                             // Send dummy data to read 2 more lsb  
  
  while (UCA1STAT & UCBUSY);                                                   // Wait for TX complete
  x = (x << 2) | UCA1RXBUF;                                                    // Read lsb & append   
  
  TI_ADC16S626_CSn_PxOUT |= TI_ADC16S626_CSn_PIN;                              // /CS disable
  
  return x;                                                                    // return previous register value  
  
}
//------------------------------------------------------------------------------
#endif