//******************************************************************************
//  Description:  This file contains definitions specific to the specific MSP430
//  chosen for this implementation.  MSP430 has multiple interfaces capable
//  of interfacing to the SPI port; each of these is defined in this file.
//
//  The source labels for the definitions (i.e., "P3SEL") can be found in
//  msp430xxxx.h.
//
//  MSP430/LMP91000 Interface Code Library v1.0
//
//   Vishy Natarajan
//   Texas Instruments Inc.
//   December 2011
//   Built with CCE Version: 4.2 and IAR Embedded Workbench Version:  5.3x
//******************************************************************************
// Change Log:
//******************************************************************************
// Version:  1.00
// Comments: Initial Release Version
//******************************************************************************
#ifndef HEADER_TI_LMP91000_MSP430_H

#define HEADER_FILE_TI_LMP91000_MSP430_H

#include "msp430.h"

//******************************************************************************
// I2C port definitions
// Adjust the values for the chosen interfaces, according to the pin
// assignments indicated in the chosen MSP430 device datasheet.
//******************************************************************************
// I2C port definitions 


#define SCL_CLOCK_DIV 0x0C                  // SCL clock devider

// USCIB0 for F552x
#define TI_LMP91000_I2C_USCIB0_PxSEL   P3SEL
#define TI_LMP91000_I2C_USCIB0_PxDIR   P3DIR
#define TI_LMP91000_I2C_USCIB0_PxOUT   P3OUT
#define TI_LMP91000_I2C_USCIB0_SDA     BIT0
#define TI_LMP91000_I2C_USCIB0_SCL     BIT1

// USCIB0 for F673x
#define TI_LMP91000_I2C_USCIB0_6xx_PxSEL   P2SEL
#define TI_LMP91000_I2C_USCIB0_6xx_PxDIR   P2DIR
#define TI_LMP91000_I2C_USCIB0_6xx_PxOUT   P2OUT
#define TI_LMP91000_I2C_USCIB0_6xx_SDA     BIT1
#define TI_LMP91000_I2C_USCIB0_6xx_SCL     BIT0


// USCIB1 for F552x
#define TI_LMP91000_I2C_USCIB1_PxSEL   P4SEL
#define TI_LMP91000_I2C_USCIB1_PxDIR   P4DIR
#define TI_LMP91000_I2C_USCIB1_PxOUT   P4OUT
#define TI_LMP91000_I2C_USCIB1_SDA     BIT1
#define TI_LMP91000_I2C_USCIB1_SCL     BIT2

// USCIB2 for F543x
#define TI_LMP91000_I2C_USCIB2_PxSEL   P9SEL
#define TI_LMP91000_I2C_USCIB2_PxDIR   P9DIR
#define TI_LMP91000_I2C_USCIB2_PxOUT   P9OUT
#define TI_LMP91000_I2C_USCIB2_SDA     BIT1
#define TI_LMP91000_I2C_USCIB2_SCL     BIT2

// USCIB3 for F543x
#define TI_LMP91000_I2C_USCIB3_PxSEL   P10SEL
#define TI_LMP91000_I2C_USCIB3_PxDIR   P10DIR
#define TI_LMP91000_I2C_USCIB3_PxOUT   P10OUT
#define TI_LMP91000_I2C_USCIB3_SDA     BIT1
#define TI_LMP91000_I2C_USCIB3_SCL     BIT2

// USART0 for F1xx
#define TI_LMP91000_I2C_USART0_PxSEL    P3SEL
#define TI_LMP91000_I2C_USART0_PxDIR    P3DIR
#define TI_LMP91000_I2C_USART0_PxOUT    P3OUT
#define TI_LMP91000_I2C_USART0_SDA      BIT1
#define TI_LMP91000_I2C_USART0_SCL      BIT3

// USCI_B0 for F261x
#define TI_LMP91000_I2C_UCB0_PxSEL     P3SEL
#define TI_LMP91000_I2C_UCB0_PxDIR     P3DIR
#define TI_LMP91000_I2C_UCB0_PxOUT     P3OUT
#define TI_LMP91000_I2C_UCB0_SDA       BIT1
#define TI_LMP91000_I2C_UCB0_SCL       BIT2

// USCI_B1 for F261x
#define TI_LMP91000_I2C_UCB1_PxSEL     P5SEL
#define TI_LMP91000_I2C_UCB1_PxDIR     P5DIR
#define TI_LMP91000_I2C_UCB1_PxOUT     P5OUT
#define TI_LMP91000_I2C_UCB1_SDA       BIT1
#define TI_LMP91000_I2C_UCB1_SCL       BIT2

//******************************************************************************
//  These constants are used to identify the chosen I2C interfaces.
//******************************************************************************
#define TI_LMP91000_SER_INTF_NULL         0
#define TI_LMP91000_SER_INTF_USCIB0_5xx   1
#define TI_LMP91000_SER_INTF_USCIB1_5xx   2
#define TI_LMP91000_SER_INTF_USCIB2_5xx   3
#define TI_LMP91000_SER_INTF_USCIB3_5xx   4
#define TI_LMP91000_SER_INTF_USART0_1xx   5
#define TI_LMP91000_SER_INTF_USCIB0       6
#define TI_LMP91000_SER_INTF_USCIB1       7
#define TI_LMP91000_SER_INTF_eUSCIB0_6xx  8

#endif                                                                         // HEADER_FILE_TI_LMP91000_MSP430_H
