//----------------------------------------------------------------------------
//  Description:  This file contains definitions specific to the hardware board.
//  Specifically, the definitions include hardware connections with the
//  LMP91000 connector port, LEDs, and switches.
//
//  MSP430/LMP91000 Interface Code Library v1.0
//
//   Vishy Natarajan
//   Texas Instruments Inc.
//   October 2011
//   Built with CCE Version: 4.2 and IAR Embedded Workbench Version:  5.3x
//------------------------------------------------------------------------------
// Change Log:
//------------------------------------------------------------------------------
// Version:  1.00
// Comments: Initial Release Version
//------------------------------------------------------------------------------
#ifndef HEADER_FILE_TI_MSP430_HARDWARE_BOARD_H

#define HEADER_FILE_TI_MSP430_HARDWARE_BOARD_H

void TI_ADC16S626_SPISetup(void);
uint16_t TI_ADC16S626_SPIReadReg(void);

#define TI_LMP91000_LED_PxOUT            P1OUT
#define TI_LMP91000_LED_PxDIR            P1DIR
#define TI_LMP91000_LED_PIN              BIT0

#define TI_LMP91000_MENB_PxDIR           P2DIR
#define TI_LMP91000_MENB_PxOUT           P2OUT
#define TI_LMP91000_MENB_PIN             BIT6                                   

#define TI_ADC16S626_CSn_PxOUT           P2OUT
#define TI_ADC16S626_CSn_PxDIR           P2DIR
#define TI_ADC16S626_CSn_PIN             BIT4                                   

// F552x USCIA1 for ADC16S626 SPI Connection
#define TI_ADC16S626_SPI_USCIA1_SIMO_PxSEL            P4SEL
#define TI_ADC16S626_SPI_USCIA1_SOMI_PxSEL            P4SEL
#define TI_ADC16S626_SPI_USCIA1_UCLK_PxSEL            P4SEL
#define TI_ADC16S626_SPI_USCIA1_SIMO_PxDIR            P4DIR
#define TI_ADC16S626_SPI_USCIA1_UCLK_PxDIR            P4DIR
#define TI_ADC16S626_SPI_USCIA1_PxIN                  P4IN
#define TI_ADC16S626_SPI_USCIA1_SIMO                  BIT4
#define TI_ADC16S626_SPI_USCIA1_SOMI                  BIT5
#define TI_ADC16S626_SPI_USCIA1_UCLK                  BIT0

// GPIO Bit Bang (pins same as USCIA1) for ADC16S626 SPI Connection
#define TI_ADC16S626_SPI_BITBANG_SIMO_PxSEL           P4SEL
#define TI_ADC16S626_SPI_BITBANG_SOMI_PxSEL           P4SEL
#define TI_ADC16S626_SPI_BITBANG_UCLK_PxSEL           P4SEL

#define TI_ADC16S626_SPI_BITBANG_PxDIR                P4DIR
#define TI_ADC16S626_SPI_BITBANG_PxOUT                P4OUT
#define TI_ADC16S626_SPI_BITBANG_PxIN                 P4IN
#define TI_ADC16S626_SPI_BITBANG_SIMO                 BIT4
#define TI_ADC16S626_SPI_BITBANG_SOMI                 BIT5
#define TI_ADC16S626_SPI_BITBANG_UCLK                 BIT0

#define TI_LMP91000_VOUT_ADC12_PIN       BIT0                                  // ADC12 Module in MSP430F5528
#define TI_LMP91000_VOUT_ADC12_PxSEL     P6SEL

#define TI_LMP91000_VOUT_ADC10_PIN       BIT2                                  // ADC10 Module in MSP430F6736
#define TI_LMP91000_VOUT_ADC10_PxSEL     P1SEL

//----------------------------------------------------------------------------
// Select which port will be used for interface to LMP91000
//----------------------------------------------------------------------------
#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB0_5xx        // 5xx, 6xx family USCIB0 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB1_5xx        // 5xx, 6xx family USCIB1 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB2_5xx        // 5xx, 6xx family USCIB2 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB3_5xx        // 5xx, 6xx family USCIB3 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USART0_1xx        // 1xx family USART0 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB0            // 2xx, 4xx family USCIB0 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_USCIB1            // 2xx, 4xx family USCIB1 I2C Interface to LMP91000
//#define TI_LMP91000_SER_INTF            TI_LMP91000_SER_INTF_eUSCIB0_6xx       // 6xx family eUSCIB0 I2C Interface to LMP91000 

#endif                                                                         // HEADER_FILE_TI_MSP430_HARDWARE_BOARD_H